echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
	[[ $(command -v pcre2test) == "" ]] && echo "Installing pcre2" && extension --install pcre2 && echo "Finished pcre2"
	[[ $MULTILIB ]] && [[ $(cat /etc/extension/installed_version.list | grep Meson_Toolchain_Files) == "" ]] && \
		echo "Installing meson_toolchain_files" && extension --install meson_toolchain_files && echo "Finished meson_toolchain_files"
# Recommended
#if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v xslt-config) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
	[[ $(command -v docutils) == "" ]] && echo "Installing py_docutils" && extension --install py_docutils && echo "Finished py_docutils"
	[ ! -d /usr/lib/python*/site-packages/packaging ] && echo "Installing py_packaging" && extension --install py_packaging && echo "Finished py_packaging"
#fi
# Optional
#if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v mako-render) == "" ]] && echo "Installing py_mako" && extension --install py_mako && echo "Finished py_mako"
	[[ $(command -v markdown_py) == "" ]] && echo "Installing py_markdown" && extension --install py_markdown && echo "Finished py_markdown"
#fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v g-ir-scanner) == "" ]]; then
	echo "glib" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "glib" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
